@@ -5,11 +5,13 @@ import random
 from hashlib import sha256
 
 from twisted.web import client, http_headers
+from ooni.utils.net import hasRawSocketPermission
+
 client._HTTP11ClientFactory.noisy = False
 
 from twisted.internet import reactor, defer
 
-from ooni.utils import log, checkForRoot
+from ooni.utils import log
 from ooni import errors
 
 try:
@@ -28,9 +30,9 @@ class GeoIPDataFilesNotFound(Exception):
 def IPToLocation(ipaddr):
     from ooni.settings import config
 
-    city_file = os.path.join(config.advanced.geoip_data_dir, 'GeoLiteCity.dat')
-    country_file = os.path.join(config.advanced.geoip_data_dir, 'GeoIP.dat')
-    asn_file = os.path.join(config.advanced.geoip_data_dir, 'GeoIPASNum.dat')
+    city_file = config.get_data_file_path('GeoIP/GeoLiteCity.dat')
+    country_file = config.get_data_file_path('GeoIP/GeoIP.dat')
+    asn_file = config.get_data_file_path('GeoIP/GeoIPASNum.dat')
 
     location = {'city': None, 'countrycode': 'ZZ', 'asn': 'AS0'}
 
@@ -79,13 +81,9 @@ def database_version():
         }
     }
 
-    geoip_data_dir = config.advanced.get("geoip_data_dir")
-    if not geoip_data_dir:
-        return version
-
     for key in version.keys():
-        geoip_file = os.path.join(geoip_data_dir, key + ".dat")
-        if not os.path.isfile(geoip_file):
+        geoip_file = config.get_data_file_path("GeoIP/" + key + ".dat")
+        if not geoip_file or not os.path.isfile(geoip_file):
             continue
         timestamp = os.stat(geoip_file).st_mtime
 
@@ -243,7 +241,8 @@ class ProbeIP(object):
         """
         Perform a UDP traceroute to determine the probes IP address.
         """
-        checkForRoot()
+        if not hasRawSocketPermission():
+            raise errors.InsufficientPrivileges
         raise NotImplemented
 
     def askTor(self):
